@@ -49,36 +49,34 @@ typedef struct zathura_dbus_s ZathuraDbus;
 /**
  * Error types
  */
-typedef enum zathura_plugin_error_e
-{
-  ZATHURA_ERROR_OK, /**< No error occurred */
-  ZATHURA_ERROR_UNKNOWN, /**< An unknown error occurred */
-  ZATHURA_ERROR_OUT_OF_MEMORY, /**< Out of memory */
-  ZATHURA_ERROR_NOT_IMPLEMENTED, /**< The called function has not been implemented */
+typedef enum zathura_plugin_error_e {
+  ZATHURA_ERROR_OK,                /**< No error occurred */
+  ZATHURA_ERROR_UNKNOWN,           /**< An unknown error occurred */
+  ZATHURA_ERROR_OUT_OF_MEMORY,     /**< Out of memory */
+  ZATHURA_ERROR_NOT_IMPLEMENTED,   /**< The called function has not been implemented */
   ZATHURA_ERROR_INVALID_ARGUMENTS, /**< Invalid arguments have been passed */
-  ZATHURA_ERROR_INVALID_PASSWORD /**< The provided password is invalid */
+  ZATHURA_ERROR_INVALID_PASSWORD   /**< The provided password is invalid */
 } zathura_error_t;
 
 /**
  * Possible information entry types
  */
-typedef enum zathura_document_information_type_e
-{
-  ZATHURA_DOCUMENT_INFORMATION_TITLE, /**< Title of the document */
-  ZATHURA_DOCUMENT_INFORMATION_AUTHOR, /**< Author of the document */
-  ZATHURA_DOCUMENT_INFORMATION_SUBJECT, /**< Subject of the document */
-  ZATHURA_DOCUMENT_INFORMATION_KEYWORDS, /**< Keywords of the document */
-  ZATHURA_DOCUMENT_INFORMATION_CREATOR, /**< Creator of the document */
-  ZATHURA_DOCUMENT_INFORMATION_PRODUCER, /**< Producer of the document */
-  ZATHURA_DOCUMENT_INFORMATION_CREATION_DATE, /**< Creation data */
+typedef enum zathura_document_information_type_e {
+  ZATHURA_DOCUMENT_INFORMATION_TITLE,             /**< Title of the document */
+  ZATHURA_DOCUMENT_INFORMATION_AUTHOR,            /**< Author of the document */
+  ZATHURA_DOCUMENT_INFORMATION_SUBJECT,           /**< Subject of the document */
+  ZATHURA_DOCUMENT_INFORMATION_KEYWORDS,          /**< Keywords of the document */
+  ZATHURA_DOCUMENT_INFORMATION_CREATOR,           /**< Creator of the document */
+  ZATHURA_DOCUMENT_INFORMATION_PRODUCER,          /**< Producer of the document */
+  ZATHURA_DOCUMENT_INFORMATION_CREATION_DATE,     /**< Creation data */
   ZATHURA_DOCUMENT_INFORMATION_MODIFICATION_DATE, /**< Modification data */
-  ZATHURA_DOCUMENT_INFORMATION_OTHER, /**< Any other information */
-  ZATHURA_DOCUMENT_INFORMATION_FORMAT /**< Format of the document */
+  ZATHURA_DOCUMENT_INFORMATION_OTHER,             /**< Any other information */
+  ZATHURA_DOCUMENT_INFORMATION_FORMAT             /**< Format of the document */
 } zathura_document_information_type_t;
 
 /**
-  * Plugin
-  */
+ * Plugin
+ */
 typedef struct zathura_plugin_s zathura_plugin_t;
 
 /**
@@ -92,23 +90,21 @@ typedef struct zathura_document_information_entry_s zathura_document_information
 /**
  * Image buffer
  */
-typedef struct zathura_image_buffer_s
-{
-  unsigned char* data; /**< Image buffer data */
-  unsigned int height; /**< Height of the image */
-  unsigned int width; /**< Width of the image */
+typedef struct zathura_image_buffer_s {
+  unsigned char* data;    /**< Image buffer data */
+  unsigned int height;    /**< Height of the image */
+  unsigned int width;     /**< Width of the image */
   unsigned int rowstride; /**< Rowstride of the image */
 } zathura_image_buffer_t;
 
 /**
  * Adjust mode
  */
-typedef enum zathura_adjust_mode_e
-{
-  ZATHURA_ADJUST_NONE, /**< No adjustment */
-  ZATHURA_ADJUST_BESTFIT, /**< Adjust to best-fit */
-  ZATHURA_ADJUST_WIDTH, /**< Adjust to width */
-  ZATHURA_ADJUST_INPUTBAR, /**< Focusing the inputbar */
+typedef enum zathura_adjust_mode_e {
+  ZATHURA_ADJUST_NONE,       /**< No adjustment */
+  ZATHURA_ADJUST_BESTFIT,    /**< Adjust to best-fit */
+  ZATHURA_ADJUST_WIDTH,      /**< Adjust to width */
+  ZATHURA_ADJUST_INPUTBAR,   /**< Focusing the inputbar */
   ZATHURA_ADJUST_MODE_NUMBER /**< Number of adjust modes */
 } zathura_adjust_mode_t;
 
@@ -133,8 +129,7 @@ ZATHURA_PLUGIN_API void zathura_image_buffer_free(zathura_image_buffer_t* buffer
  * The coordinate system has its origin in the left upper corner. The x axes
  * goes to the right, the y access goes down.
  */
-typedef struct zathura_rectangle_s
-{
+typedef struct zathura_rectangle_s {
   double x1; /**< X coordinate of point 1 */
   double y1; /**< Y coordinate of point 1 */
   double x2; /**< X coordinate of point 2 */
@@ -144,28 +139,25 @@ typedef struct zathura_rectangle_s
 /**
  * Image structure
  */
-typedef struct zathura_image_s
-{
+typedef struct zathura_image_s {
   zathura_rectangle_t position; /**< Coordinates of the image */
-  void* data; /**< Custom data of the plugin */
+  void* data;                   /**< Custom data of the plugin */
 } zathura_image_t;
 
 /**
  * Possible link types
  */
-typedef enum zathura_link_type_e
-{
-  ZATHURA_LINK_INVALID, /**< Invalid type */
-  ZATHURA_LINK_NONE, /**< No action */
-  ZATHURA_LINK_GOTO_DEST, /**< Links to a page */
+typedef enum zathura_link_type_e {
+  ZATHURA_LINK_INVALID,     /**< Invalid type */
+  ZATHURA_LINK_NONE,        /**< No action */
+  ZATHURA_LINK_GOTO_DEST,   /**< Links to a page */
   ZATHURA_LINK_GOTO_REMOTE, /**< Links to a page */
-  ZATHURA_LINK_URI, /**< Links to an external source */
-  ZATHURA_LINK_LAUNCH, /**< Links to an external source */
-  ZATHURA_LINK_NAMED /**< Links to an external source */
+  ZATHURA_LINK_URI,         /**< Links to an external source */
+  ZATHURA_LINK_LAUNCH,      /**< Links to an external source */
+  ZATHURA_LINK_NAMED        /**< Links to an external source */
 } zathura_link_type_t;
 
-typedef enum zathura_link_destination_type_e
-{
+typedef enum zathura_link_destination_type_e {
   ZATHURA_LINK_DESTINATION_UNKNOWN,
   ZATHURA_LINK_DESTINATION_XYZ,
   ZATHURA_LINK_DESTINATION_FIT,
@@ -177,16 +169,15 @@ typedef enum zathura_link_destination_type_e
   ZATHURA_LINK_DESTINATION_FITBV
 } zathura_link_destination_type_t;
 
-typedef struct zathura_link_target_s
-{
+typedef struct zathura_link_target_s {
   zathura_link_destination_type_t destination_type;
-  char* value; /**< Value */
+  char* value;              /**< Value */
   unsigned int page_number; /**< Page number */
-  double left; /**< Left coordinate */
-  double right; /**< Right coordinate */
-  double top; /**< Top coordinate */
-  double bottom; /**< Bottom coordinate */
-  double zoom; /**< Zoom */
+  double left;              /**< Left coordinate */
+  double right;             /**< Right coordinate */
+  double top;               /**< Top coordinate */
+  double bottom;            /**< Bottom coordinate */
+  double zoom;              /**< Zoom */
 } zathura_link_target_t;
 
 /**
@@ -197,8 +188,7 @@ typedef struct zathura_link_s zathura_link_t;
 /**
  * Index element
  */
-typedef struct zathura_index_element_s
-{
+typedef struct zathura_index_element_s {
   char* title; /**< Title of the element */
   zathura_link_t* link;
 } zathura_index_element_t;
@@ -206,8 +196,7 @@ typedef struct zathura_index_element_s
 /**
  * Form type
  */
-typedef enum zathura_form_type_e
-{
+typedef enum zathura_form_type_e {
   ZATHURA_FORM_CHECKBOX, /**< Checkbox */
   ZATHURA_FORM_TEXTFIELD /**< Textfield */
 } zathura_form_type_t;
@@ -215,20 +204,18 @@ typedef enum zathura_form_type_e
 /**
  * Form element
  */
-typedef struct zathura_form_s
-{
+typedef struct zathura_form_s {
   zathura_rectangle_t position; /**< Position */
-  zathura_form_type_t type; /**< Type */
+  zathura_form_type_t type;     /**< Type */
 } zathura_form_t;
 
 /**
  * Jump
  */
-typedef struct zathura_jump_s
-{
-  unsigned int page;
+typedef struct zathura_jump_s {
   double x;
   double y;
+  unsigned int page;
 } zathura_jump_t;
 
 /**
@@ -263,8 +250,7 @@ ZATHURA_PLUGIN_API girara_list_t* zathura_document_information_entry_list_new(vo
  * @return A new entry or NULL if an error occurred
  */
 ZATHURA_PLUGIN_API zathura_document_information_entry_t*
-zathura_document_information_entry_new(zathura_document_information_type_t
-    type, const char* value);
+zathura_document_information_entry_new(zathura_document_information_type_t type, const char* value);
 
 /**
  * Frees a document information entry
@@ -281,8 +267,7 @@ typedef struct zathura_content_type_context_s zathura_content_type_context_t;
 /**
  * Device scaling structure.
  */
-typedef struct zathura_device_factors_s
-{
+typedef struct zathura_device_factors_s {
   double x;
   double y;
 } zathura_device_factors_t;
@@ -304,9 +289,9 @@ typedef enum zathura_signature_state_e {
  * Signature information
  */
 typedef struct zathura_signature_info_s {
-  char*                     signer;
-  GDateTime*                time;
-  zathura_rectangle_t       position;
+  char* signer;
+  GDateTime* time;
+  zathura_rectangle_t position;
   zathura_signature_state_t state;
 } zathura_signature_info_t;
 
@@ -324,4 +309,17 @@ ZATHURA_PLUGIN_API zathura_signature_info_t* zathura_signature_info_new(void);
  */
 ZATHURA_PLUGIN_API void zathura_signature_info_free(zathura_signature_info_t* signature);
 
+/**
+ * Quickmark list entry
+ */
+struct zathura_mark_s {
+  int key;           /**> Marks key */
+  double position_x; /**> Horizontal adjustment */
+  double position_y; /**> Vertical adjustment */
+  unsigned int page; /**> Page number */
+  double zoom;       /**> Zoom level */
+};
+
+typedef struct zathura_mark_s zathura_mark_t;
+
 #endif // TYPES_H
